;; Generated package description from map.el  -*- no-byte-compile: t -*-
(define-package "map" "3.3.1.0.20250101.73917" "Map manipulation functions" '((emacs "26")) :commit "b36b1be491e0b19062fa38ee197aa3daeba96415" :url "https://elpa.gnu.org/packages/map.html" :authors '(("Nicolas Petton" . "nicolas@petton.fr")) :maintainer '(nil . "emacs-devel@gnu.org") :keywords '("extensions" "lisp"))
